@@ -29,7 +29,7 @@ namespace GLib {
 	public class Markup {
 		private Markup () {}
 		
-		[DllImport("libglib-2.0-0.dll", CallingConvention=CallingConvention.Cdecl)]
+		[DllImport("libglib-2.0-0.dll")]
 		static extern IntPtr g_markup_escape_text (IntPtr text, int len);
 		
 		static public string EscapeText (string s)
